@@ -5,7 +5,7 @@ import time
 import os
 import psutil
 
-from shakenfist import config
+from shakenfist.config import config
 from shakenfist.daemons import daemon
 from shakenfist.daemons import external_api as external_api_daemon
 from shakenfist.daemons import cleaner as cleaner_daemon
@@ -27,7 +27,7 @@ def restore_instances():
     # Ensure all instances for this node are defined
     networks = []
     instances = []
-    for inst in list(db.get_instances(only_node=config.parsed.get('NODE_NAME'))):
+    for inst in list(db.get_instances(only_node=config.NODE_NAME)):
         for iface in db.get_instance_interfaces(inst['uuid']):
             if not iface['network_uuid'] in networks:
                 networks.append(iface['network_uuid'])
@@ -86,9 +86,8 @@ def main():
     setproctitle.setproctitle(daemon.process_name('main'))
 
     # Log configuration on startup
-    config.parsed.parse()
-    for key in config.parsed.config:
-        LOG.info('Configuration item %s = %s' % (key, config.parsed.get(key)))
+    for key, value in config.dict().items():
+        LOG.info('Configuration item %s = %s' % (key, value))
 
     daemon.set_log_level(LOG, 'main')
 
@@ -113,22 +112,22 @@ def main():
         # Bootstrap the floating network in the Networks table
         floating_network = db.get_network('floating')
         if not floating_network:
-            db.create_floating_network(config.parsed.get('FLOATING_NETWORK'))
+            db.create_floating_network(config.get('FLOATING_NETWORK'))
             floating_network = net.from_db('floating')
 
         subst = {
             'physical_bridge': util.get_safe_interface_name(
-                'phy-br-%s' % config.parsed.get('NODE_EGRESS_NIC')),
-            'physical_nic': config.parsed.get('NODE_EGRESS_NIC')
+                'phy-br-%s' % config.get('NODE_EGRESS_NIC')),
+            'physical_nic': config.get('NODE_EGRESS_NIC')
         }
 
         if not util.check_for_interface(subst['physical_bridge']):
             # NOTE(mikal): Adding the physical interface to the physical bridge
-            # is considered outside the scope of the orchestration software as it
-            # will cause the node to lose network connectivity. So instead all we
-            # do is create a bridge if it doesn't exist and the wire everything up
-            # to it. We can do egress NAT in that state, even if floating IPs
-            # don't work.
+            # is considered outside the scope of the orchestration software as
+            # it will cause the node to lose network connectivity. So instead
+            # all we do is create a bridge if it doesn't exist and the wire
+            # everything up to it. We can do egress NAT in that state, even if
+            # floating IPs don't work.
             with util.RecordedOperation('create physical bridge', None):
                 # No locking as read only
                 ipm = db.get_ipmanager('floating')
@@ -139,20 +138,23 @@ def main():
                 util.execute(None,
                              'ip link set %(physical_bridge)s up' % subst)
                 util.execute(None,
-                             'ip addr add %(master_float)s/%(netmask)s dev %(physical_bridge)s' % subst)
+                             'ip addr add %(master_float)s/%(netmask)s '
+                             'dev %(physical_bridge)s' % subst)
 
                 util.execute(None,
-                             'iptables -A FORWARD -o %(physical_nic)s -i %(physical_bridge)s -j ACCEPT' % subst)
+                             'iptables -A FORWARD -o %(physical_nic)s '
+                             '-i %(physical_bridge)s -j ACCEPT' % subst)
                 util.execute(None,
-                             'iptables -A FORWARD -i %(physical_nic)s -o %(physical_bridge)s -j ACCEPT' % subst)
+                             'iptables -A FORWARD -i %(physical_nic)s '
+                             '-o %(physical_bridge)s -j ACCEPT' % subst)
                 util.execute(None,
-                             'iptables -t nat -A POSTROUTING -o %(physical_nic)s -j MASQUERADE' % subst)
+                             'iptables -t nat -A POSTROUTING '
+                             '-o %(physical_nic)s -j MASQUERADE' % subst)
 
     def _audit_daemons():
         running_daemons = []
         for pid in DAEMON_PIDS:
             running_daemons.append(DAEMON_PIDS[pid])
-        LOG.info('Daemons running: %s' % ', '.join(sorted(running_daemons)))
 
         for d in DAEMON_IMPLEMENTATIONS:
             if d not in running_daemons:
