@@ -3,6 +3,7 @@ import mock
 from shakenfist import exceptions
 from shakenfist import scheduler
 from shakenfist.tests import test_shakenfist
+from shakenfist.config import SFConfig
 
 
 class FakeInstance(object):
@@ -57,6 +58,17 @@ class FakeDB(object):
         return self.metrics[node_name]
 
 
+fake_config = SFConfig(
+    NODE_NAME='node01',
+    SCHEDULER_CACHE_TIMEOUT=30,
+    CPU_OVERCOMMIT_RATIO=16.0,
+    RAM_OVERCOMMIT_RATIO=1.5,
+    RAM_SYSTEM_RESERVATION=5.0,
+    NETWORK_NODE_IP='10.0.0.1',
+    LOG_METHOD_TRACE=1,
+)
+
+
 class SchedulerTestCase(test_shakenfist.ShakenFistTestCase):
     def setUp(self):
         super(SchedulerTestCase, self).setUp()
@@ -66,24 +78,7 @@ class SchedulerTestCase(test_shakenfist.ShakenFistTestCase):
         self.recorded_op.start()
         self.addCleanup(self.recorded_op.stop)
 
-        # Fake system configuration
-        def fake_config(key):
-            data = {
-                'NODE_NAME': 'node01',
-                'SCHEDULER_CACHE_TIMEOUT': 30,
-                'CPU_OVERCOMMIT_RATIO': 16,
-                'RAM_OVERCOMMIT_RATIO': 1.5,
-                'RAM_SYSTEM_RESERVATION': 5.0,
-                'NETWORK_NODE_IP': '10.0.0.1',
-                'LOG_METHOD_TRACE': 1,
-            }
-
-            if key not in data:
-                raise Exception('fake_config() Unknown key')
-            return data[key]
-
-        self.mock_config = mock.patch('shakenfist.config.parsed.get',
-                                      fake_config)
+        self.mock_config = mock.patch('shakenfist.db.config', fake_config)
         self.mock_config.start()
         self.addCleanup(self.mock_config.stop)
 
