@@ -16,7 +16,7 @@ import traceback
 from oslo_concurrency import processutils
 
 from shakenfist import db
-from shakenfist import config
+from shakenfist.config import config
 from shakenfist import logutil
 
 
@@ -65,7 +65,7 @@ class RecordedOperation():
 
 def is_network_node():
     """Test if this node is the network node."""
-    return config.parsed.get('NODE_IP') == config.parsed.get('NETWORK_NODE_IP')
+    return config.NODE_IP == config.NETWORK_NODE_IP
 
 
 def check_for_interface(name, up=False):
@@ -182,7 +182,7 @@ def extract_power_state(libvirt, domain):
                  libvirt.VIR_DOMAIN_PMSUSPENDED]:
         return 'paused'
 
-    # Covers all "runnning states": BLOCKED, NOSTATE,
+    # Covers all "running states": BLOCKED, NOSTATE,
     # RUNNING, SHUTDOWN
     return 'on'
 
